<%inherit file="admin_basewithmenu.html" /> <%block name="head"> ${parent.head()}
<%block name="menu2">
×

### Create Key

Name:

Total limit:

Hourly limit:

Processing

×

### Change total request limit

Name:

Total limit:

Processing

×

### Change hourly request limit

Name:

Hourly limit:

Processing

×

### Delete a Key

Key to delete:

Processing

×

### Reset hourly request counter

Counter to reset:

Processing